@@ -1,5 +1,3 @@
-# $Id: trip.split.R 89 2013-03-24 16:34:38Z sluque $
-
 ## TODO:
 ## tidier!
 ##-----------------------------------------------------------------------------
@@ -14,6 +12,8 @@
 ## bound.dates <- seq(min(tr$tms)-1, max(tr$tms)+1, length=5)
 ## trip.list <- trip.split.exact(tr, bound.dates)
 
+##' @importFrom maptools spRbind
+##' @rdname trip-internal
 .tripRbind <- function (obj, x) {
     ## not needed, and not possible since classes imported using
     ## NAMESPACE MDS 2012-10-09
@@ -28,6 +28,7 @@
     trip(x, tor1)
 }
 
+##' @rdname trip-internal
 .single.trip.split <- function(tr1, boundary.dates) {
     diff.d <- diff(unclass(boundary.dates))
     if (any(diff.d < 0))
@@ -105,10 +106,95 @@
     lapply(res, trip, tor)
 }
 
-trip.split.exact <- function(x, dates) {
-    .Deprecated("cut.trip")
-    cut(x, dates)
-}
+
+
+
+#' 
+#' Split trip events into exact time-based boundaries.
+#' 
+#' 
+#' Split trip events within a single object into exact time boundaries, adding
+#' interpolated coordinats as required.
+#' 
+#' 
+#' Motion between boundaries is assumed linear and extra coordinates are added
+#' at the cut points.
+#' 
+#' @param x A trip object.
+#' @param dates A vector of date-time boundaries. These must encompass all the
+#' time range of the entire trip object.
+#' @param \dots Unused arguments.
+#' @return
+#' 
+#' A list of trip objects, named by the time boundary in which they lie.
+#' @author Michael D. Sumner and Sebastian Luque
+#' @seealso See also \code{\link{tripGrid}}.
+#' @keywords manip chron
+#' @examples
+#' 
+#' \dontrun{
+#' set.seed(66)
+#' d <- data.frame(x=1:100, y=rnorm(100, 1, 10),
+#'                 tms=Sys.time() + c(seq(10, 1000, length=50),
+#'                 seq(100, 1500, length=50)), id=gl(2, 50))
+#' coordinates(d) <- ~x+y
+#' tr <- trip(d, c("tms", "id"))
+#' 
+#' bound.dates <- seq(min(tr$tms) - 1, max(tr$tms) + 1, length=5)
+#' trip.list <- cut(tr, bound.dates)
+#' bb <- bbox(tr)
+#' cn <- c(20, 8)
+#' g <- GridTopology(bb[, 1], apply(bb, 1, diff) / (cn - 1), cn)
+#' 
+#' tg <- tripGrid(tr, grid=g)
+#' tg <- as.image.SpatialGridDataFrame(tg)
+#' tg$x <- tg$x - diff(tg$x[1:2]) / 2
+#' tg$y <- tg$y - diff(tg$y[1:2]) / 2
+#' 
+#' op <- par(mfcol=c(4, 1))
+#' for (i in 1:length(trip.list)) {
+#'   plot(coordinates(tr), pch=16, cex=0.7)
+#'   title(names(trip.list)[i], cex.main=0.9)
+#'   lines(trip.list[[i]])
+#'   abline(h=tg$y, v=tg$x, col="grey")
+#'   image(tripGrid(trip.list[[i]], grid=g), interpolate=FALSE,
+#'   col=c("white", grey(seq(0.2, 0.7,  length=256))),add=TRUE)
+#'   abline(h=tg$y, v=tg$x,  col="grey")
+#'   lines(trip.list[[i]])
+#'   points(trip.list[[i]], pch=16, cex=0.7)
+#' }
+#' 
+#' par(op)
+#' print("you may need to resize the window to see the grid data")
+#' 
+#' cn <- c(200, 80)
+#' g <- GridTopology(bb[, 1], apply(bb, 1, diff) / (cn - 1), cn)
+#' 
+#' tg <- tripGrid(tr, grid=g)
+#' tg <- as.image.SpatialGridDataFrame(tg)
+#' tg$x <- tg$x - diff(tg$x[1:2]) / 2
+#' tg$y <- tg$y - diff(tg$y[1:2]) / 2
+#' 
+#' op <- par(mfcol=c(4, 1))
+#' for (i in 1:length(trip.list)) {
+#'   plot(coordinates(tr), pch=16, cex=0.7)
+#'   title(names(trip.list)[i], cex.main=0.9)
+#'   image(tripGrid(trip.list[[i]], grid=g, method="density", sigma=1),
+#'         interpolate=FALSE,
+#'         col=c("white", grey(seq(0.2, 0.7, length=256))),
+#'         add=TRUE)
+#'   lines(trip.list[[i]])
+#'   points(trip.list[[i]], pch=16, cex=0.7)
+#' }
+#' 
+#' par(op)
+#' print("you may need to resize the window to see the grid data")
+#' 
+#' }
+#' 
+#' @method cut trip
+#' @S3method cut trip
+#' @export cut.trip
 cut.trip <- function(x, dates, ...) {
     tor <- getTORnames(x)
     ids <- unique(x[[tor[2]]])
@@ -149,8 +235,3 @@ cut.trip <- function(x, dates, ...) {
 }
 
 
-
-###_ + Emacs local variables
-## Local variables:
-## allout-layout: (+ : 0)
-## End:
